@@ -146,3 +146,10 @@ def cache(reload=True,cache_file='cache.pkl'):
         return dec_inner
     return dec_outer
 
+def empty_to_None(x):
+    if x=='':
+        return None
+    else:
+        return x
+
+
